@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2022 David Gobbi
+  Copyright (c) 2012-2024 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -180,11 +180,12 @@ int main(int argc, char *argv[])
         // write the DICOM series with the compiler
         fname = a->GetValue(i);
         char outpath[128];
-        sprintf(outpath, outfile, fileBasename(fname.c_str()));
+        snprintf(outpath, sizeof(outpath), outfile,
+                 fileBasename(fname.c_str()));
         compiler->SetFileName(outpath);
         const char *instanceUID =
           data->Get(i, DC::SOPInstanceUID).GetCharData();
-        if (instanceUID == 0)
+        if (instanceUID == nullptr)
         {
           instanceUID =
             data->Get(i, DC::MediaStorageSOPInstanceUID).GetCharData();
