@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2022 David Gobbi
+  Copyright (c) 2012-2024 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -60,7 +60,7 @@ void dicomtocsv_version(FILE *file, const char *cp)
 {
   fprintf(file, "%s %s\n", cp, DICOM_VERSION);
   fprintf(file, "\n"
-    "Copyright (c) 2012-2022, David Gobbi.\n\n"
+    "Copyright (c) 2012-2024, David Gobbi.\n\n"
     "This software is distributed under an open-source license.  See the\n"
     "Copyright.txt file that comes with the vtk-dicom source distribution.\n");
 }
@@ -71,10 +71,11 @@ void dicomtocsv_usage(FILE *file, const char *cp)
   fprintf(file, "usage:\n"
     "  %s [options] <directory>\n\n", cp);
   fprintf(file, "options:\n"
-    "  -k tag=value      Provide a key to be queried and matched.\n"
+    "  -k tag=value      Provide a tag or key to be queried and matched.\n"
     "  -q <query.txt>    Provide a file to describe the find query.\n"
     "  -u <uids.txt>     Provide a file that contains a list of UIDs.\n"
     "  -o <data.csv>     Provide a file for the query results.\n"
+    "  -maxdepth n       Set the maximum directory depth for search.\n"
     "  --default         Add to default query instead of replacing it.\n"
     "  --first-nonzero   Search series for first nonzero value of each key.\n"
     "  --all-unique      Report all unique values within each series.\n"
@@ -99,10 +100,11 @@ void dicomtocsv_help(FILE *file, const char *cp)
   dicomtocsv_usage(file, cp);
   fprintf(file, "\n"
     "Dump selected metadata from a DICOM directory to a csv file.\n"
+    "\n"
     "For each attribute to be extracted, the tag can be given with \"-k\"\n"
     "(the \"-k\" option can be repeated as many times as needed).  Tags can\n"
     "given in hexadecimal GGGG,EEEE format, or in text format as specified\n"
-    "in the DICOM dictionary.  Alternately, the tags can be listed in a\n"
+    "in the DICOM dictionary key.  Alternately, the tags can be listed in a\n"
     "query file given with the \"-q\" option (one tag per line).\n"
     "Attributes nested within sequences can be specified by giving a tag\n"
     "path e.g. \"-k Tag1/Tag2/Tag3\".  Either a forward slash or a backslash\n"
@@ -128,6 +130,56 @@ const char *dicomtocsv_basename(const char *filename)
   return cp;
 }
 
+// dot product
+double dicomtocsv_dotprod(const double x[3], const double y[3])
+{
+  return x[0]*y[0] + x[1]*y[1] + x[2]*y[2];
+}
+
+// check if two orientations are equal or nearly equal
+bool dicomtocsv_same_orientation(const vtkDICOMValue& ov1,
+                                 const vtkDICOMValue& ov2)
+{
+  // start with a simple check for exact equality
+  if (ov1 == ov2)
+  {
+    return true;
+  }
+
+  // do a numerical check with tolerance
+  double o1[6] = { 0.0, 0.0, 0.0, 0.0, 0.0, 0.0 };
+  double o2[6] = { 0.0, 0.0, 0.0, 0.0, 0.0, 0.0 };
+  ov1.GetValues(o1, 6);
+  ov2.GetValues(o2, 6);
+
+  // check the row and column orientation vectors
+  for (int i = 0; i < 2; i++)
+  {
+    // use dot product to compute sine of angle between vectors
+    double a = dicomtocsv_dotprod(&o1[3*i], &o2[3*i]);
+    double b = dicomtocsv_dotprod(&o1[3*i], &o1[3*i]);
+    double c = dicomtocsv_dotprod(&o2[3*i], &o2[3*i]);
+    // use "d" to hold the square of the sine
+    double d = 1.0;
+    const double tol = 1e-4;
+    // apply forumula only if both vectors are nonzero
+    if (b > 0.0 && c > 0.0)
+    {
+      // compute square of sine of angle between o1 and o2 vector
+      d = 1.0 - (a*a)/(b*c);
+      // compare against tolerance (due to sine small angle approximation,
+      // the tolerance is essentially applied to angle itself, in radians)
+      if (d > tol*tol)
+      {
+        return false;
+      }
+    }
+  }
+
+  return true;
+}
+
+
 typedef vtkDICOMVR VR;
 
 // Observer for DICOM errors
@@ -141,7 +193,7 @@ public:
     VTK_DICOM_OVERRIDE;
   void SetMetaData(vtkDICOMMetaData *meta) { this->MetaData = meta; }
 protected:
-  ErrorObserver() : MetaData(0) {}
+  ErrorObserver() : MetaData(nullptr) {}
   ErrorObserver(const ErrorObserver& c) : vtkCommand(c) {}
   void operator=(const ErrorObserver&) {}
   vtkDICOMMetaData *MetaData;
@@ -477,7 +529,7 @@ void dicomtocsv_write(vtkDICOMDirectory *finder,
     {
       total += finder->GetFileNamesForSeries(k)->GetNumberOfValues();
     }
-    p->Execute(NULL, vtkCommand::StartEvent, NULL);
+    p->Execute(nullptr, vtkCommand::StartEvent, nullptr);
   }
 
   for (int j = 0; j < finder->GetNumberOfStudies(); j++)
@@ -541,15 +593,44 @@ void dicomtocsv_write(vtkDICOMDirectory *finder,
         for (int ii = 0; ii < meta->GetNumberOfInstances(); ii++)
         {
           parser->SetIndex(ii);
-          parser->SetFileName(a->GetValue(ii));
+          parser->SetFileName(a->GetValue(ii).c_str());
           parser->Update();
         }
       }
 
       // this loop is only for the "image" level
       int m = (level >= 4 ? meta->GetNumberOfInstances() : 1);
-      for (int jj = 0; jj < m; jj++)
+      int n = (m == 1 ? meta->GetNumberOfInstances() : 1);
+      for (int kk = 0; kk < m; kk++)
       {
+        // this will be zero unless level >= 4
+        int jj = kk;
+
+        // whether to report only specific images from series/study
+        if (level < 4 && n > 2)
+        {
+          // check for localizers at the beginning or end of series,
+          // and skip them if they are present
+          vtkDICOMTag tag(DC::ImageOrientationPatient);
+          vtkDICOMDataElementIterator iter = meta->Find(tag);
+          if (iter != meta->End() && iter->IsPerInstance())
+          {
+            vtkDICOMValue ov1 = iter->GetValue(0);
+            vtkDICOMValue ov2 = iter->GetValue(1);
+            vtkDICOMValue ov3 = iter->GetValue(n - 1);
+            bool match1 = dicomtocsv_same_orientation(ov1, ov2);
+            bool match2 = dicomtocsv_same_orientation(ov2, ov3);
+            if (match1 && !match2)
+            {
+              n -= 1; // skip the last image
+            }
+            else if (match2 && !match1)
+            {
+              jj += 1; // skip the first image
+            }
+          }
+        }
+
         // print the value of each tag
         for (size_t i = 0; i < ql->size(); i++)
         {
@@ -566,20 +647,19 @@ void dicomtocsv_write(vtkDICOMDirectory *finder,
           bool done = false;
 
           // this loop is only needed if all images are to be checked
-          int n = (m == 1 ? meta->GetNumberOfInstances() : 1);
           if (level >= 4)
           {
             // we will probe one instance (instance jj)
             n = jj+1;
           }
-          else if (n > 1)
+          else if (n > jj+1)
           {
             // do a quick check to see if value is same for all instances
             vtkDICOMTag tag = tagPath.GetHead();
             if ((tag.GetGroup() & 0x0001) == 0)
             {
               vtkDICOMDataElementIterator iter = meta->Find(tag);
-              n = ((iter == meta->End() || !iter->IsPerInstance()) ? 1 : n);
+              n = ((iter == meta->End() || !iter->IsPerInstance()) ? jj+1 : n);
             }
           }
           for (int ii = jj; ii < n && !done; ii++)
@@ -593,7 +673,7 @@ void dicomtocsv_write(vtkDICOMDirectory *finder,
             SearchState &head = tstack.back();
             head.p = tagPath;
             head.q = &query;
-            head.m = 0;
+            head.m = nullptr;
             head.n = head.m + 1;
 
             while (!tstack.empty())
@@ -624,7 +704,7 @@ void dicomtocsv_write(vtkDICOMDirectory *finder,
                   tag = adapter->ResolvePrivateTag(tag, creator);
                 }
               }
-              const vtkDICOMValue *vptr = 0;
+              const vtkDICOMValue *vptr = nullptr;
               if (mitem)
               {
                 vptr = &mitem->Get(tag);
@@ -641,12 +721,12 @@ void dicomtocsv_write(vtkDICOMDirectory *finder,
               }
               if (vptr && !vptr->IsValid())
               {
-                vptr = 0;
+                vptr = nullptr;
               }
               // check if we have reached the end of a tag path
               if (!tpath.HasTail())
               {
-                if (vptr != 0)
+                if (vptr != nullptr)
                 {
                   std::string t = value_as_string(*vptr);
 
@@ -704,7 +784,7 @@ void dicomtocsv_write(vtkDICOMDirectory *finder,
                   }
                 }
               }
-              else if (vptr != 0)
+              else if (vptr != nullptr)
               {
                 // go one level deeper into the query
                 qitem = qitem->Get(tpath.GetHead()).GetSequenceData();
@@ -763,7 +843,7 @@ void dicomtocsv_write(vtkDICOMDirectory *finder,
           count += numberOfFiles;
           double progress = (static_cast<double>(count)/
                              static_cast<double>(total));
-          p->Execute(NULL, vtkCommand::ProgressEvent, &progress);
+          p->Execute(nullptr, vtkCommand::ProgressEvent, &progress);
         }
       }
     }
@@ -771,7 +851,7 @@ void dicomtocsv_write(vtkDICOMDirectory *finder,
 
   if (p)
   {
-    p->Execute(NULL, vtkCommand::EndEvent, NULL);
+    p->Execute(nullptr, vtkCommand::EndEvent, nullptr);
   }
 }
 
@@ -785,6 +865,7 @@ int MAINMACRO(int argc, char *argv[])
 
   int rval = 0;
   int scandepth = std::numeric_limits<int>::max();
+  bool followSymlinks = true;
   QueryTagList qtlist;
   vtkDICOMItem query;
   std::vector<std::string> oplist;
@@ -800,7 +881,7 @@ int MAINMACRO(int argc, char *argv[])
   int level = 3; // default to series level
 
   vtkSmartPointer<vtkStringArray> a = vtkSmartPointer<vtkStringArray>::New();
-  const char *ofile = 0;
+  const char *ofile = nullptr;
 
   // always query SpecificCharacterSet
   query.Set(DC::SpecificCharacterSet, vtkDICOMValue(VR::CS));
@@ -846,7 +927,15 @@ int MAINMACRO(int argc, char *argv[])
   for (int argi = 1; argi < argc; argi++)
   {
     const char *arg = argv[argi];
-    if (strcmp(arg, "-q") == 0 || strcmp(arg, "-o") == 0)
+    if (strcmp(arg, "-P") == 0)
+    {
+      followSymlinks = false;
+    }
+    else if (strcmp(arg, "-L") == 0)
+    {
+      followSymlinks = true;
+    }
+    else if (strcmp(arg, "-q") == 0 || strcmp(arg, "-o") == 0)
     {
       if (argi + 1 == argc || argv[argi+1][0] == '-')
       {
@@ -899,6 +988,16 @@ int MAINMACRO(int argc, char *argv[])
         return 1;
       }
     }
+    else if (strcmp(arg, "-maxdepth") == 0)
+    {
+      ++argi;
+      if (argi == argc)
+      {
+        fprintf(stderr, "%s must be followed by an argument.\n\n", arg);
+        return 1;
+      }
+      scandepth = static_cast<int>(atol(argv[argi]));
+    }
     else if (strcmp(arg, "--default") == 0)
     {
       dicomtocsv_default(level, &query, &qtlist);
@@ -999,7 +1098,7 @@ int MAINMACRO(int argc, char *argv[])
   }
 
   FILE *fp = stdout;
-  FILE *fp1 = NULL;
+  FILE *fp1 = nullptr;
 
   if (ofile)
   {
@@ -1007,7 +1106,7 @@ int MAINMACRO(int argc, char *argv[])
     fp1 = fopen(ofile, "wb");
 #else
     // use wide chars to avoid narrowing to local character set
-    int n = MultiByteToWideChar(CP_UTF8, 0, ofile, -1, NULL, 0);
+    int n = MultiByteToWideChar(CP_UTF8, 0, ofile, -1, nullptr, 0);
     wchar_t *wofile = new wchar_t[n];
     MultiByteToWideChar(CP_UTF8, 0, ofile, -1, wofile, n);
     fp1 = _wfopen(wofile, L"wb");
@@ -1074,6 +1173,7 @@ int MAINMACRO(int argc, char *argv[])
       finder->SetQueryFilesToAlways();
     }
     finder->SetScanDepth(scandepth);
+    finder->SetFollowSymlinks(followSymlinks);
     finder->SetFindQuery(query);
     finder->Update();
 
