@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2022 David Gobbi
+  Copyright (c) 2012-2024 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -42,11 +42,11 @@ public:
   //@{
   //! Find the dictionary entry for the given tag.
   static vtkDICOMDictEntry FindDictEntry(const vtkDICOMTag tag) {
-    return vtkDICOMDictionary::FindDictEntry(tag, 0); }
+    return vtkDICOMDictionary::FindDictEntry(tag, nullptr); }
 
   //! Find the dictionary for the given key.
   static vtkDICOMDictEntry FindDictEntry(const char *key) {
-    return vtkDICOMDictionary::FindDictEntry(key, 0); }
+    return vtkDICOMDictionary::FindDictEntry(key, nullptr); }
   //@}
 
   //@{
