@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2022 David Gobbi
+  Copyright (c) 2012-2024 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -18,7 +18,7 @@
 #include <stddef.h>
 
 //----------------------------------------------------------------------------
-const char *vtkDICOMImageCodec::UIDs[21] = {
+const char *vtkDICOMImageCodec::UIDs[24] = {
   "1.2.840.10008.1.2.1",     // LittleEndian
   "1.2.840.10008.1.2.2",     // BigEndian
   "1.2.840.10008.1.2.5",     // RLE
@@ -28,8 +28,8 @@ const char *vtkDICOMImageCodec::UIDs[21] = {
   "1.2.840.10008.1.2.4.70",  // JPEGPrediction
   "1.2.840.10008.1.2.4.80",  // JPEGLS
   "1.2.840.10008.1.2.4.81",  // JPEGLSConstrained
-  "1.2.840.10008.1.2.4.90",  // JPEG2K
-  "1.2.840.10008.1.2.4.91",  // JPEG2KLossless
+  "1.2.840.10008.1.2.4.90",  // JPEG2KLossless
+  "1.2.840.10008.1.2.4.91",  // JPEG2K
   "1.2.840.10008.1.2.4.100", // MPEG2ML
   "1.2.840.10008.1.2.4.101", // MPEG2HL
   "1.2.840.10008.1.2.4.102", // MPEG4HPL41
@@ -39,7 +39,10 @@ const char *vtkDICOMImageCodec::UIDs[21] = {
   "1.2.840.10008.1.2.4.106", // MPEG4HPL42Stereo
   "1.2.840.10008.1.2.4.107", // HEVCMPL51
   "1.2.840.10008.1.2.4.108", // HEVCM10PL51
-  0
+  "1.2.840.10008.1.2.4.110", // JPEGXLLossless
+  "1.2.840.10008.1.2.4.111", // JPEGXLRecomp
+  "1.2.840.10008.1.2.4.112", // JPEGXL
+  nullptr
 };
 
 //----------------------------------------------------------------------------
@@ -228,7 +231,7 @@ int vtkDICOMImageCodec::EncodeRLE(
   unsigned int n = spp*bps;
   if (n == 0 || n > 15)
   {
-    *destP = 0;
+    *destP = nullptr;
     *destSizeP = 0;
     return BadPixelFormat;
   }
