@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2022 David Gobbi
+  Copyright (c) 2012-2024 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -94,7 +94,7 @@ public:
    */
   vtkDICOMDataElementIterator Find(vtkDICOMTag tag) {
     vtkDICOMDataElement *e = this->FindDataElement(tag);
-    return (e != 0 ? e : &this->Tail); }
+    return (e != nullptr ? e : &this->Tail); }
   //@}
 
   //@{
