@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2022 David Gobbi
+  Copyright (c) 2012-2024 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -323,6 +323,20 @@ public:
   //@}
 #endif
 
+  //@{
+  //! Control registration of image codecs (DCMTK-specific).
+  /*!
+   *  If the reader has been compiled with DCMTK support, RegisterCodecs()
+   *  allows manual registration of the DCMTK codecs by the application.
+   *  If you do not call this method, the reader will automatically register
+   *  the codecs when it is instantiated.  The registration is internally
+   *  guarded by a refererence count, and every RegisterCodecs() call must
+   *  eventually be matched by an UnRegisterCodecs() call.
+   */
+  static void RegisterCodecs();
+  static void UnRegisterCodecs();
+  //@}
+
 protected:
   vtkDICOMReader();
   ~vtkDICOMReader() VTK_DICOM_OVERRIDE;
@@ -510,4 +524,23 @@ private:
 #endif
 };
 
+//! @cond
+//! Initializer (Schwarz counter).
+/*!
+ *  This ensures that the vtkDICOMReader module is initialized before
+ *  any other module that includes this header file.
+ */
+class VTKDICOM_EXPORT vtkDICOMReaderInitializer
+{
+public:
+  vtkDICOMReaderInitializer();
+  ~vtkDICOMReaderInitializer();
+private:
+  vtkDICOMReaderInitializer(const vtkDICOMReaderInitializer&);
+  vtkDICOMReaderInitializer& operator=(const vtkDICOMReaderInitializer&);
+};
+
+static vtkDICOMReaderInitializer vtkDICOMReaderInitializerInstance;
+//! @endcond
+
 #endif // vtkDICOMReader_h
