@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2022 David Gobbi
+  Copyright (c) 2012-2024 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -58,11 +58,11 @@ int vtkDICOMUtilities::CompareUIDs(const char *u1, const char *u2)
 {
   int r = 0;
 
-  if (u1 == 0 || u2 == 0)
+  if (u1 == nullptr || u2 == nullptr)
   {
     // if one or both are null
-    r = (u2 == 0 ? r : -1);
-    r = (u1 == 0 ? r : 1);
+    r = (u2 == nullptr ? r : -1);
+    r = (u1 == nullptr ? r : 1);
   }
   else
   {
@@ -112,7 +112,7 @@ long long vtkDICOMUtilities::GetUniversalTime()
 #else
 
   struct timeval tv;
-  gettimeofday(&tv, 0);
+  gettimeofday(&tv, nullptr);
   return (tv.tv_sec*1000000ll + tv.tv_usec);
 
 #endif
@@ -221,9 +221,9 @@ std::string vtkDICOMUtilities::GenerateDateTime(
     long long zst = zs/1000000ll;
     tzs[0] = (zst < 0 ? '-' : '+');
     zst = (zst < 0 ? -zst : zst);
-    sprintf(&tzs[1], "%02d%02d",
-            static_cast<int>((zst/3600)%24),
-            static_cast<int>((zst%3600)/60));
+    snprintf(&tzs[1], sizeof(tzs) - 1, "%02d%02d",
+             static_cast<int>((zst/3600)%24),
+             static_cast<int>((zst%3600)/60));
     z = tzs;
   }
 
@@ -266,8 +266,8 @@ std::string vtkDICOMUtilities::GenerateDateTime(
 
   // create a DICOM datetime string
   char dt[84];
-  sprintf(dt, "%04d%02d%02d%02d%02d%02d.%06d%s",
-          y, m, d, H, M, S, us, z);
+  snprintf(dt, sizeof(dt), "%04d%02d%02d%02d%02d%02d.%06d%s",
+           y, m, d, H, M, S, us, z);
 
   return dt;
 }
@@ -361,7 +361,7 @@ bool vtkDICOMUtilities::IsDICOMFile(const char *filename)
 {
   unsigned char buffer[256];
 
-  if (filename == 0)
+  if (filename == nullptr)
   {
     return false;
   }
