@@ -514,7 +514,7 @@ void vtkNIFTIHeader::PrintSelf(ostream& os, vtkIndent indent)
 //----------------------------------------------------------------------------
 void vtkNIFTIHeader::SetStringValue(char *x, const char *y, size_t n)
 {
-  if (y == 0)
+  if (y == nullptr)
   {
     y = "";
   }
