@@ -39,9 +39,19 @@
 #include "vtkDICOMModule.h" // For export macro
 #include "vtkDICOMConfig.h" // For configuration details
 
-class vtkNIFTIHeader;
+// Declare VTK classes within VTK's optional namespace
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_BEGIN
+#endif
+
 class vtkMatrix4x4;
 
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_END
+#endif
+
+class vtkNIFTIHeader;
+
 struct nifti_1_header;
 
 //----------------------------------------------------------------------------
@@ -165,7 +175,7 @@ public:
 
 protected:
   vtkNIFTIReader();
-  ~vtkNIFTIReader();
+  ~vtkNIFTIReader() VTK_DICOM_OVERRIDE;
 
   //! Read the header information.
   int RequestInformation(
