@@ -37,7 +37,17 @@
 #include "vtkDICOMModule.h" // For export macro
 #include "vtkDICOMConfig.h" // For configuration details
 
+// Declare VTK classes within VTK's optional namespace
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_BEGIN
+#endif
+
 class vtkMatrix4x4;
+
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_END
+#endif
+
 class vtkNIFTIHeader;
 
 class VTKDICOM_EXPORT vtkNIFTIWriter : public vtkImageWriter
@@ -181,7 +191,7 @@ public:
 
 protected:
   vtkNIFTIWriter();
-  ~vtkNIFTIWriter();
+  ~vtkNIFTIWriter() VTK_DICOM_OVERRIDE;
 
   //! Generate the header information for the file.
   int GenerateHeader(vtkInformation *info, bool singleFile);
