@@ -45,7 +45,7 @@ vtkStandardNewMacro(vtkScancoCTReader);
 vtkScancoCTReader::vtkScancoCTReader()
 {
   this->InitializeHeader();
-  this->RawHeader = 0;
+  this->RawHeader = nullptr;
 
   // ISQ uses a lower-left-hand origin
   this->FileLowerLeft = true;
@@ -506,12 +506,12 @@ int vtkScancoCTReader::ReadISQHeader(std::istream *file, unsigned long bytesRead
   month = ((month > 12 || month < 1) ? 0 : month);
   static const char *months[] = { "XXX", "JAN", "FEB", "MAR", "APR", "MAY",
     "JUN", "JUL", "AUG", "SEP", "OCT", "NOV", "DEC" };
-  sprintf(this->CreationDate, "%d-%s-%d %02d:%02d:%02d.%03d",
-          (day % 100), months[month], (year % 10000),
-          (hour % 100), (minute % 100), (second % 100), (milli % 1000));
-  sprintf(this->ModificationDate, "%d-%s-%d %02d:%02d:%02d.%03d",
-          (day % 100), months[month], (year % 10000),
-          (hour % 100), (minute % 100), (second % 100), (milli % 1000));
+  snprintf(this->CreationDate, 32, "%d-%s-%d %02d:%02d:%02d.%03d",
+           (day % 100), months[month], (year % 10000),
+           (hour % 100), (minute % 100), (second % 100), (milli % 1000));
+  snprintf(this->ModificationDate, 32, "%d-%s-%d %02d:%02d:%02d.%03d",
+           (day % 100), months[month], (year % 10000),
+           (hour % 100), (minute % 100), (second % 100), (milli % 1000));
 
   this->SetDataByteOrderToLittleEndian();
   this->SetFileDimensionality(3);
@@ -575,7 +575,7 @@ int vtkScancoCTReader::ReadISQHeader(std::istream *file, unsigned long bytesRead
   // decode the extended header (lots of guesswork)
   if (headerSize >= 2048)
   {
-    char *calHeader = 0;
+    char *calHeader = nullptr;
     int calHeaderSize = 0;
     h = this->RawHeader + 512;
     unsigned long hskip = 1;
@@ -980,7 +980,7 @@ int vtkScancoCTReader::RequestInformation(
   this->InitializeHeader();
 
   const char *filename = this->FileName;
-  if (filename == 0)
+  if (filename == nullptr)
   {
     vtkErrorMacro("A filename must be specified");
     return 0;
@@ -1098,17 +1098,17 @@ int vtkScancoCTReader::RequestData(
 
   data->GetPointData()->GetScalars()->SetName("ImageFile");
 
-  const char *filename = 0;
+  const char *filename = nullptr;
   if (this->FileNames && this->FileNames->GetNumberOfValues() == 1)
   {
-    filename = this->FileNames->GetValue(0);
+    filename = this->FileNames->GetValue(0).c_str();
   }
   else
   {
     filename = this->GetFileName();
   }
 
-  if (filename == 0)
+  if (filename == nullptr)
   {
     vtkErrorMacro("A FileName must be provided");
     return 0;
@@ -1155,7 +1155,7 @@ int vtkScancoCTReader::RequestData(
   outSize *= zsize;
 
   // For the input (compressed) data
-  char *input = 0;
+  char *input = nullptr;
   size_t size = 0;
 
   if (this->Compression == 0x00b1)
