@@ -17,11 +17,7 @@ if (!(t)) \
   rval |= 1; \
 }
 
-#ifdef VTK_IN_VTK
 int TestDICOMValue(int argc, char *argv[])
-#else
-int main(int argc, char *argv[])
-#endif
 {
   int rval = 0;
   const char *exename = (argc > 0 ? argv[0] : "TestDICOMValue");
@@ -617,3 +613,10 @@ int main(int argc, char *argv[])
 
   return rval;
 }
+
+#ifdef VTK_DICOM_SEPARATE_TESTS
+int main(int argc, char *argv[])
+{
+  return TestDICOMValue(argc, argv);
+}
+#endif
